@@ -1,12 +1,14 @@
+from importlib.util import spec_from_file_location
 from imblearn.ensemble import BalancedRandomForestClassifier
 from sklearn.model_selection import train_test_split
 import os
 import pandas as pd
-import numpy as np
 from rdkit import Chem
 from rdkit.Chem import Descriptors, rdMolDescriptors
 from rdkit.ML.Descriptors import MoleculeDescriptors
 import pickle
+import wget
+
 class model_selection:
     def __init__(self, 
                  saved_spe_model , 
@@ -35,15 +37,6 @@ class model_selection:
         else:
             print('Where is the saved lcms scaler!!!?')
             return
-    def calculate_descriptors_df(self, smiles, ipc_avg=False):
-        mol = Chem.MolFromSmiles(smiles)
-        if names is None:
-            names = [d[0] for d in Descriptors._descList]
-        calc = MoleculeDescriptors.MolecularDescriptorCalculator(names)
-        descriptors = calc.CalcDescriptors(mol)
-        if 'Ipc' in names and ipc_avg:
-            descriptors['Ipc'] = [Descriptors.Ipc(mol, avg=True)]
-        return descriptors
     
     def calculate_descriptors(self, smiles, ipc_avg=False):
         mol = Chem.MolFromSmiles(smiles)
@@ -54,7 +47,7 @@ class model_selection:
 
         descs = [calc.CalcDescriptors(mol)]
         descs_df = pd.DataFrame(descs, columns=names)
-        print(descs_df)
+        # print(descs_df)
         if 'Ipc' in names and ipc_avg:
             descs['Ipc'] = Descriptors.Ipc(mol, avg=True)
         return descs_df
@@ -74,12 +67,34 @@ class model_selection:
         return y
     
 if __name__ == '__main__':
-    smiles = "CC1CCN(CC1N(C)C2=NC=NC3=C2C=CN3)C(=O)CC#N"
-    model_object = model_selection('/Users/yycheung/Analysis project/purifAI/base-purifai/purifai/spe_brf_model.pkl', 
-                 '/Users/yycheung/Analysis project/purifAI/base-purifai/purifai/spe_scaler.pkl',
-                 '/Users/yycheung/Analysis project/purifAI/base-purifai/purifai/lcms_brf_model.pkl',
-                 '/Users/yycheung/Analysis project/purifAI/base-purifai/purifai/lcms_scaler.pkl')
-    descs = [model_object.calculate_descriptors(smiles)]
     
-    print(f'The SPE method you should use is : {model_object.RunSPEPrediction(smiles)}')
-    print(f'The LCMS method you should use is : {model_object.RunLCMSPrediction(smiles)}')
\ No newline at end of file
+    smiles = "CC1CCN(CC1N(C)C2=NC=NC3=C2C=CN3)C(=O)CC#N"
+    
+    cwd = os.getcwd()
+    url = 'https://github.com/jenamis/purifAI/raw/main/machine_learning/SPE/models/'
+    if not os.path.exists(os.getcwd() + '/spe_xgb_model.pkl'):
+        wget.download(url+ 'spe_xgb_model.pkl')
+    if not os.path.exists(os.getcwd() + '/spe_scaler.pkl'):
+        wget.download(url+ 'spe_scaler.pkl')
+        
+    url= 'https://github.com/jenamis/purifAI/raw/main/machine_learning/LCMS/models/'
+    if not os.path.exists(os.getcwd() + '/lcms_xgb_model.pkl'):
+        wget.download(url+ 'lcms_xgb_model.pkl')
+    if not os.path.exists(os.getcwd() + '/lcms_scaler.pkl'):
+        wget.download(url+ 'lcms_scaler.pkl')
+        
+    spe_xgb_model = cwd + '/spe_xgb_model.pkl'
+    spe_scaler = cwd + '/spe_scaler.pkl'
+    lcms_xgb_model = cwd + '/lcms_xgb_model.pkl'
+    lcms_scaler = cwd + '/lcms_scaler.pkl'
+
+    model_predictor = model_selection(spe_xgb_model, 
+                                      spe_scaler,
+                                      lcms_xgb_model,
+                                      lcms_scaler)
+    
+    model_selection = model_selection(spe_xgb_model, spe_scaler, lcms_xgb_model, lcms_scaler)
+    descs = [model_selection.calculate_descriptors(smiles)]
+    
+    print(f'The SPE method you should use is : {model_selection.RunSPEPrediction(smiles)}')
+    print(f'The LCMS method you should use is : {model_selection.RunLCMSPrediction(smiles)}')
\ No newline at end of file
